@@ -9,13 +9,15 @@
 package CGI::FormBuilder::Field::hidden;
 
 use strict;
+use warnings;
+no  warnings 'uninitialized';
 
 use CGI::FormBuilder::Util;
 use CGI::FormBuilder::Field::text;
 use base 'CGI::FormBuilder::Field::text';
 
-our $REVISION = do { (my $r='$Revision: 64 $') =~ s/\D+//g; $r };
-our $VERSION = '3.0401';
+our $REVISION = do { (my $r='$Revision: 91 $') =~ s/\D+//g; $r };
+our $VERSION = '3.05';
 
 sub script {
     return '';  # hidden fields are never checked
