@@ -97,12 +97,14 @@ CGI::FormBuilder::Multi - Create multi-page FormBuilder forms
 =cut
 
 use strict;
+use warnings;
+no  warnings 'uninitialized';
 
 use CGI::FormBuilder;
 use CGI::FormBuilder::Util;
 
-our $REVISION = do { (my $r='$Revision: 64 $') =~ s/\D+//g; $r };
-our $VERSION = '3.0401';
+our $REVISION = do { (my $r='$Revision: 91 $') =~ s/\D+//g; $r };
+our $VERSION = '3.05';
 
 our %DEFAULT = (
     pagename => '_page',
@@ -346,7 +348,7 @@ L<CGI::FormBuilder>
 
 =head1 REVISION
 
-$Id: Multi.pm 64 2006-09-07 18:08:27Z nwiger $
+$Id: Multi.pm 91 2006-12-18 10:27:01Z nwiger $
 
 =head1 AUTHOR
 
