@@ -25,12 +25,14 @@ CGI::FormBuilder::Template::Text - FormBuilder interface to Text::Template
 
 use Carp;
 use strict;
+use warnings;
+no  warnings 'uninitialized';
 
 use CGI::FormBuilder::Util;
 use Text::Template;
 
-our $REVISION = do { (my $r='$Revision: 64 $') =~ s/\D+//g; $r };
-our $VERSION = '3.0401';
+our $REVISION = do { (my $r='$Revision: 91 $') =~ s/\D+//g; $r };
+our $VERSION = '3.05';
 
 sub new {
     my $self  = shift;
@@ -128,7 +130,7 @@ The following methods are provided (usually only used internally):
 
 =head2 engine
 
-Returns a reference to the C<HTML::Template> object
+Returns a reference to the C<Text::Template> object
 
 =head2 prepare
 
@@ -282,7 +284,7 @@ L<CGI::FormBuilder>, L<CGI::FormBuilder::Template>, L<Text::Template>
 
 =head1 REVISION
 
-$Id: Text.pm 64 2006-09-07 18:08:27Z nwiger $
+$Id: Text.pm 91 2006-12-18 10:27:01Z nwiger $
 
 =head1 AUTHOR
 
