@@ -23,11 +23,13 @@ CGI::FormBuilder::Test - Test harness for FormBuilder
 =cut
 
 use strict;
+use warnings;
+no  warnings 'uninitialized';
 
 use CGI::FormBuilder::Util;
 
-our $REVISION = do { (my $r='$Revision: 64 $') =~ s/\D+//g; $r };
-our $VERSION = '3.0401';
+our $REVISION = do { (my $r='$Revision: 91 $') =~ s/\D+//g; $r };
+our $VERSION = '3.05';
 our $DEBUG = 0;
 
 use Exporter;
@@ -51,7 +53,7 @@ sub outfile ($) {
 
 =head1 REVISION
 
-$Id: Test.pm 64 2006-09-07 18:08:27Z nwiger $
+$Id: Test.pm 91 2006-12-18 10:27:01Z nwiger $
 
 =head1 AUTHOR
 
